==> phpAdsNew-2.0.tar.gz: phpAdsNew-2.0/language/german/maintenance.lang.php <==
<?php // $Revision: 1.1.2.5 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2003 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/

// German
// Main strings
$GLOBALS['strChooseSection']			= "Auswahlbereich";


// Priority
$GLOBALS['strRecalculatePriority']		= "Rekalkulieren der Prioritten";
$GLOBALS['strHighPriorityCampaigns']		= "Kampagnen mit hoher Prioritt";
$GLOBALS['strAdViewsAssigned']		= "Festgelegte AdViews";
$GLOBALS['strLowPriorityCampaigns']		= " Kampagnen mit geringer Prioritt ";
$GLOBALS['strPredictedAdViews']		= "Prognostizierte AdViews";
$GLOBALS['strPriorityDaysRunning']		= "Die Prognose fr die tgliche Bannerauslieferung basiert auf Statistiken von {days} Tagen. ";
$GLOBALS['strPriorityBasedLastWeek']		= "Die Prognose basiert auf den Daten dieser und der vergangenen Woche. ";
$GLOBALS['strPriorityBasedLastDays']		= "Die Prognose basiert auf den Daten der letzten Tage. ";
$GLOBALS['strPriorityBasedYesterday']		= "Die Prognose basiert auf den Daten von gestern. ";
$GLOBALS['strPriorityNoData']			= "Fr eine zuverlssige Prognose ber die heute mgliche Anzahl von AdViews stehen fr nicht ausreichend Daten zur Verfgung.  Die Festlegung der Prioritten wird daher nur auf in Echtzeit erstellte Statistiken gesttzt sein. ";
$GLOBALS['strPriorityEnoughAdViews']		= "Es werden ausreichend AdViews zur Verfgung stehen, um die Kampagnen mit hoher Prioritt bedienen zu knnen. ";
$GLOBALS['strPriorityNotEnoughAdViews']		= "Es ist ungewi, ob ausreichend AdViews zur Verfgung stehen werden, um die Anforderungen durch Kampagnen mit hoher Prioritt befriedigen zu knnen.";


// Banner cache
$GLOBALS['strRebuildBannerCache']		= "Bannercache erneuern";
$GLOBALS['strBannerCacheExplaination']		= "
	Im Bannercache werden Kopien der HTML-Codes, die fr die Bannerdarstellung notwendig sind, vorgehalten. Durch den Bannercache wird die Auslieferung beschleunigt,
	denn der HTML-Code mu nicht bei jeder Auslieferung neu generiert werden. Weil im 
Bannercache die URL als Direktadressierung, verknpft mit dem Standort von ".$phpAds_productname." nebst dem Banner vorliegt, mu der Bannercache aktualisiert werden, wenn sein
	Standort verschoben wird.";


// Cache
$GLOBALS['strCache']			= "Cache fr Bannerauslieferung";
$GLOBALS['strAge']				= "Alter";
$GLOBALS['strRebuildDeliveryCache']			= "Cache wird erneuert";
$GLOBALS['strDeliveryCacheExplaination']		= "
	Der Cache fr Bannerauslieferung wird zur Beschleunigung der Bannerauslieferung bentigt. Im Cache sind Kopien von jedem Banner, der mit der Zone verbunden (verlinkt) ist. Dadurch, das die aktuellen Banner im Cache vorgehalten sind,  wird eine Reihe von Datenbankabfragen gespart. Der Cache wird jedesmal bei nderungen der Zone oder dem verknpften Banner erneuert. Um dennoch beralterung vorzubeugen, wird der Cache stndlich automatisch erneuert. Der Vorgang kann zustzlich manuell angestoen werden.";
$GLOBALS['strDeliveryCacheSharedMem']		= "
	Der gemeinsam genutzte Speicher wird vom Cache fr Bannerauslieferung benutzt.";
$GLOBALS['strDeliveryCacheDatabase']		= "
	Die Datenbank wird zur Zeit vom Cache fr Bannerauslieferung benutzt.";
$GLOBALS['strDeliveryCacheFiles']		= "
	Der Cache fr Bannerauslieferung wird zur Zeit in mehrere Dateien gespeichert.";


// Storage
$GLOBALS['strStorage']				= "Speicherung";
$GLOBALS['strMoveToDirectory']		= "Bilder aus der Datenbank in ein Verzeichnis verschieben ";
$GLOBALS['strStorageExplaination']		= "
	Bilddateien fr lokale Banner werden in der Datenbank oder in einem lokalen Verzeichnis gespeichert. 
	Das Speichern in einem lokalen Verzeichnis anstelle in der Datenbank vermindert die Ladezeit.";


// Storage
$GLOBALS['strStatisticsExplaination']		= "
	Sie haben als Darstellung <i>kompakte Statistiken</i> gewhlt, ltere Statistiken sind im detaillierten Format. 
	Sollen diese (lteren) detaillierten Statistiken in das kompakte Format konvertiert werden?";


// Product Updates
$GLOBALS['strSearchingUpdates']		= "Sehe nach neuen Updates. Bitte warten...";
$GLOBALS['strAvailableUpdates']			= "Vorhandene Updates";
$GLOBALS['strDownloadZip']			= "Download (.zip)";
$GLOBALS['strDownloadGZip']			= "Download (.tar.gz)";

$GLOBALS['strUpdateAlert']		= "Eine neue Version von ".$phpAds_productname." ist verfgbar.                 \\n\\nWerden weitere Informationen dazu gewnscht?";
$GLOBALS['strUpdateAlertSecurity']	= "Eine neue Version von ".$phpAds_productname." ist verfgbar.                 \\n\\n
Eine kurzfristige Aktualisierung  Ihres Systems \\n
wird empfohlen, da in der neuen Version eine oder \\n
mehrere Sicherheitselemente berarbeitet wurden.";

$GLOBALS['strUpdateServerDown']			= "
    Aus unbekannten Grnden ist es nicht mglich, nach Informationen <br>
	zu neuen Updates zu prfen. Versuchen Sie es spter noch einmal.
";

$GLOBALS['strNoNewVersionAvailable']		= "
	Ihre Version von ".$phpAds_productname." ist aktuell. Ein Update ist nicht erforderlich.
";

$GLOBALS['strNewVersionAvailable']		= "
	<b>Eine neue Version von ".$phpAds_productname." ist verfgbar.</b><br> 
	Eine Aktualisierung wird empfohlen, da einige vorhandenen Probleme behoben und neue Leistungsmerkmale integriert wurden. Weitergehende Information finden sich in der beigefgten Dokumentation.";

$GLOBALS['strSecurityUpdate']			= "
	<b>Die schnellstmgliche Durchfhrung des Updates wird empfohlen, da eine Reihe von Sicherheitsproblemen behoben wurden.</b> 
Ihre Version von ".$phpAds_productname." ist gegen illegale Angriffe mglicherweise nicht ausreichen gesichert. Weitergehende Information finden sich in der beigefgten Dokumentation.";


$GLOBALS['strNotAbleToCheck']			= "
	Auf Ihrem Server ist die XML-Erweiterung nicht verfgbar. ".$phpAds_productname." kann nicht prfen, ob eine neuere Version vorliegt.";

$GLOBALS['strForUpdatesLookOnWebsite']	= "
	Informationen ber neue Versionen .befinden sich auf unserer Webseite.";

$GLOBALS['strClickToVisitWebsite']		= "	Zu unserer Webseite ";

$GLOBALS['strCurrentlyUsing'] 			= "Sie nutzen derzeit";
$GLOBALS['strRunningOn']				= "laufend auf";
$GLOBALS['strAndPlain']				= "und";



// Stats conversion
$GLOBALS['strConverting']			= "Konvertierung";
$GLOBALS['strConvertingStats']			= "Statistiken werden konvertiert...";
$GLOBALS['strConvertStats']			= "Statistiken konvertieren";
$GLOBALS['strConvertAdViews']			= "AdViews sind konvertiert,";
$GLOBALS['strConvertAdClicks']			= "AdClicks sind konvertiert...";
$GLOBALS['strConvertNothing']			= "Nichts zu konvertieren...";
$GLOBALS['strConvertFinished']			= "Fertig...";

$GLOBALS['strConvertExplaination']		= "
	Fr die statistische Auswertung verwenden Sie kompakte Darstellung. Es liegen <br>
	noch ltere Statistiken in detailliertem Format vor. Solange diese detaillierten Statistiken <br>
	nicht in das kompakte Format konvertiert sind, knnen sie auf dieser Seite nicht angezeigt<br>
	werden. Eine Sicherung der Datenbank vor dem Konvertierungslauf ist empfohlen!  <br>
	Wollen Sie die detaillierten Statistiken in das kompakte Format umwandeln? <br>
";

$GLOBALS['strConvertingExplaination']		= "
	Alle verbliebene Statistiken im detaillierten Format werden in das kompakte umgewandelt. <br>
	Die Dauer des Vorganges ist abhngig von der Anzahl protokollierten Vorgnge. Es knnte <br>
	einige Minuten dauern. Bitte warten Sie bis zum Ende des Konvertierungslauf, bevor Sie <br>
	andere Seiten. Unten wird ein Protokoll der vorgenommenen Datenbankmodifikationen angezeigt. <br>
";

$GLOBALS['strConvertFinishedExplaination']  	= "
	Der Konvertierungslauf war erfolgreich.  Die Daten stehen nun wieder zur
	Verfgung. Nachfolgend ist ein Protokoll aller vorgenommenen Datenbankmodifikationen.<br>
";

?>

==> phpAdsNew-2.0.7.tar.gz: phpAdsNew-2.0.7/language/german/maintenance.lang.php <==
<?php // $Revision: 1.1.2.5 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2005 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/

// German
// Main strings
$GLOBALS['strChooseSection']			= "Auswahlbereich";


// Priority
$GLOBALS['strRecalculatePriority']		= "Rekalkulieren der Prioritten";
$GLOBALS['strHighPriorityCampaigns']		= "Kampagnen mit hoher Prioritt";
$GLOBALS['strAdViewsAssigned']		= "Festgelegte AdViews";
$GLOBALS['strLowPriorityCampaigns']		= " Kampagnen mit geringer Prioritt ";
$GLOBALS['strPredictedAdViews']		= "Prognostizierte AdViews";
$GLOBALS['strPriorityDaysRunning']		= "Die Prognose fr die tgliche Bannerauslieferung basiert auf Statistiken von {days} Tagen. ";
$GLOBALS['strPriorityBasedLastWeek']		= "Die Prognose basiert auf den Daten dieser und der vergangenen Woche. ";
$GLOBALS['strPriorityBasedLastDays']		= "Die Prognose basiert auf den Daten der letzten Tage. ";
$GLOBALS['strPriorityBasedYesterday']		= "Die Prognose basiert auf den Daten von gestern. ";
$GLOBALS['strPriorityNoData']			= "Fr eine zuverlssige Prognose ber die heute mgliche Anzahl von AdViews stehen fr nicht ausreichend Daten zur Verfgung.  Die Festlegung der Prioritten wird daher nur auf in Echtzeit erstellte Statistiken gesttzt sein. ";
$GLOBALS['strPriorityEnoughAdViews']		= "Es werden ausreichend AdViews zur Verfgung stehen, um die Kampagnen mit hoher Prioritt bedienen zu knnen. ";
$GLOBALS['strPriorityNotEnoughAdViews']		= "Es ist ungewi, ob ausreichend AdViews zur Verfgung stehen werden, um die Anforderungen durch Kampagnen mit hoher Prioritt befriedigen zu knnen.";


// Banner cache
$GLOBALS['strRebuildBannerCache']		= "Bannercache erneuern";
$GLOBALS['strBannerCacheExplaination']		= "
	Im Bannercache werden Kopien der HTML-Codes, die fr die Bannerdarstellung notwendig sind, vorgehalten. Durch den Bannercache wird die Auslieferung beschleunigt,
	denn der HTML-Code mu nicht bei jeder Auslieferung neu generiert werden. Weil im 
Bannercache die URL als Direktadressierung, verknpft mit dem Standort von ".$phpAds_productname." nebst dem Banner vorliegt, mu der Bannercache aktualisiert werden, wenn sein
	Standort verschoben wird.";


// Cache
$GLOBALS['strCache']			= "Cache fr Bannerauslieferung";
$GLOBALS['strAge']				= "Alter";
$GLOBALS['strRebuildDeliveryCache']			= "Cache wird erneuert";
$GLOBALS['strDeliveryCacheExplaination']		= "
	Der Cache fr Bannerauslieferung wird zur Beschleunigung der Bannerauslieferung bentigt. Im Cache sind Kopien von jedem Banner, der mit der Zone verbunden (verlinkt) ist. Dadurch, das die aktuellen Banner im Cache vorgehalten sind,  wird eine Reihe von Datenbankabfragen gespart. Der Cache wird jedesmal bei nderungen der Zone oder dem verknpften Banner erneuert. Um dennoch beralterung vorzubeugen, wird der Cache stndlich automatisch erneuert. Der Vorgang kann zustzlich manuell angestoen werden.";
$GLOBALS['strDeliveryCacheSharedMem']		= "
	Der gemeinsam genutzte Speicher wird vom Cache fr Bannerauslieferung benutzt.";
$GLOBALS['strDeliveryCacheDatabase']		= "
	Die Datenbank wird zur Zeit vom Cache fr Bannerauslieferung benutzt.";
$GLOBALS['strDeliveryCacheFiles']		= "
	Der Cache fr Bannerauslieferung wird zur Zeit in mehrere Dateien gespeichert.";


// Storage
$GLOBALS['strStorage']				= "Speicherung";
$GLOBALS['strMoveToDirectory']		= "Bilder aus der Datenbank in ein Verzeichnis verschieben ";
$GLOBALS['strStorageExplaination']		= "
	Bilddateien fr lokale Banner werden in der Datenbank oder in einem lokalen Verzeichnis gespeichert. 
	Das Speichern in einem lokalen Verzeichnis anstelle in der Datenbank vermindert die Ladezeit.";


// Storage
$GLOBALS['strStatisticsExplaination']		= "
	Sie haben als Darstellung <i>kompakte Statistiken</i> gewhlt, ltere Statistiken sind im detaillierten Format. 
	Sollen diese (lteren) detaillierten Statistiken in das kompakte Format konvertiert werden?";


// Product Updates
$GLOBALS['strSearchingUpdates']		= "Suche nach neuen Updates. Bitte warten...";
$GLOBALS['strAvailableUpdates']			= "Vorhandene Updates";
$GLOBALS['strDownloadZip']			= "Download (.zip)";
$GLOBALS['strDownloadGZip']			= "Download (.tar.gz)";

$GLOBALS['strUpdateAlert']		= "Eine neue Version von ".$phpAds_productname." ist verfgbar.                 \\n\\nWerden weitere Informationen dazu gewnscht?";
$GLOBALS['strUpdateAlertSecurity']	= "Eine neue Version von ".$phpAds_productname." ist verfgbar.                 \\n\\n
Eine kurzfristige Aktualisierung  Ihres Systems \\n
wird empfohlen, da in der neuen Version eine oder \\n
mehrere Sicherheitselemente berarbeitet wurden.";

$GLOBALS['strUpdateServerDown']			= "
    Aus unbekannten Grnden ist es nicht mglich, nach Informationen <br>
	zu neuen Updates zu prfen. Versuchen Sie es spter noch einmal.
";

$GLOBALS['strNoNewVersionAvailable']		= "
	Ihre Version von ".$phpAds_productname." ist aktuell. Ein Update ist nicht erforderlich.
";

$GLOBALS['strNewVersionAvailable']		= "
	<b>Eine neue Version von ".$phpAds_productname." ist verfgbar.</b><br> 
	Eine Aktualisierung wird empfohlen, da einige vorhandenen Probleme behoben und neue Leistungsmerkmale integriert wurden. Weitergehende Information finden sich in der beigefgten Dokumentation.";

$GLOBALS['strSecurityUpdate']			= "
	<b>Die schnellstmgliche Durchfhrung des Updates wird empfohlen, da eine Reihe von Sicherheitsproblemen behoben wurden.</b> 
Ihre Version von ".$phpAds_productname." ist gegen illegale Angriffe mglicherweise nicht ausreichen gesichert. Weitergehende Information finden sich in der beigefgten Dokumentation.";


$GLOBALS['strNotAbleToCheck']			= "
	Auf Ihrem Server ist die XML-Erweiterung nicht verfgbar. ".$phpAds_productname." kann nicht prfen, ob eine neuere Version vorliegt.";

$GLOBALS['strForUpdatesLookOnWebsite']	= "
	Informationen ber neue Versionen .befinden sich auf unserer Webseite.";

$GLOBALS['strClickToVisitWebsite']		= "	Zu unserer Webseite ";

$GLOBALS['strCurrentlyUsing'] 			= "Sie nutzen derzeit";
$GLOBALS['strRunningOn']				= "mit";
$GLOBALS['strAndPlain']				= "und";



// Stats conversion
$GLOBALS['strConverting']			= "Konvertierung";
$GLOBALS['strConvertingStats']			= "Statistiken werden konvertiert...";
$GLOBALS['strConvertStats']			= "Statistiken konvertieren";
$GLOBALS['strConvertAdViews']			= "AdViews sind konvertiert,";
$GLOBALS['strConvertAdClicks']			= "AdClicks sind konvertiert...";
$GLOBALS['strConvertNothing']			= "Nichts zu konvertieren...";
$GLOBALS['strConvertFinished']			= "Fertig...";

$GLOBALS['strConvertExplaination']		= "
	Fr die statistische Auswertung verwenden Sie kompakte Darstellung. Es liegen <br>
	noch ltere Statistiken in detailliertem Format vor. Solange diese detaillierten Statistiken <br>
	nicht in das kompakte Format konvertiert sind, knnen sie auf dieser Seite nicht angezeigt<br>
	werden. Eine Sicherung der Datenbank vor dem Konvertierungslauf ist empfohlen!  <br>
	Wollen Sie die detaillierten Statistiken in das kompakte Format umwandeln? <br>
";

$GLOBALS['strConvertingExplaination']		= "
	Alle verbliebene Statistiken im detaillierten Format werden in das kompakte umgewandelt. <br>
	Die Dauer des Vorganges ist abhngig von der Anzahl protokollierten Vorgnge. Es knnte <br>
	einige Minuten dauern. Bitte warten Sie bis zum Ende des Konvertierungslauf, bevor Sie <br>
	andere Seiten. Unten wird ein Protokoll der vorgenommenen Datenbankmodifikationen angezeigt. <br>
";

$GLOBALS['strConvertFinishedExplaination']  	= "
	Der Konvertierungslauf war erfolgreich.  Die Daten stehen nun wieder zur
	Verfgung. Nachfolgend ist ein Protokoll aller vorgenommenen Datenbankmodifikationen.<br>
";

?>
